@@ -9,7 +9,16 @@ var setForEach = hasSet && Set.prototype.forEach;
 var booleanValueOf = Boolean.prototype.valueOf;
 var objectToString = Object.prototype.toString;
 
+var inspectCustom = require('./util.inspect').custom;
+var inspectSymbol = (inspectCustom && isSymbol(inspectCustom)) ? inspectCustom : null;
+
 module.exports = function inspect_ (obj, opts, depth, seen) {
+    if (!opts) opts = {};
+
+    if (has(opts, 'quoteStyle') && (opts.quoteStyle !== 'single' && opts.quoteStyle !== 'double')) {
+        throw new TypeError('option "quoteStyle" must be "single" or "double"');
+    }
+
     if (typeof obj === 'undefined') {
         return 'undefined';
     }
@@ -19,8 +28,9 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
     if (typeof obj === 'boolean') {
         return obj ? 'true' : 'false';
     }
+
     if (typeof obj === 'string') {
-        return inspectString(obj);
+        return inspectString(obj, opts);
     }
     if (typeof obj === 'number') {
       if (obj === 0) {
@@ -29,8 +39,6 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
       return String(obj);
     }
 
-    if (!opts) opts = {};
-
     var maxDepth = typeof opts.depth === 'undefined' ? 5 : opts.depth;
     if (typeof depth === 'undefined') depth = 0;
     if (depth >= maxDepth && maxDepth > 0 && typeof obj === 'object') {
@@ -62,7 +70,7 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
         var s = '<' + String(obj.nodeName).toLowerCase();
         var attrs = obj.attributes || [];
         for (var i = 0; i < attrs.length; i++) {
-            s += ' ' + attrs[i].name + '="' + quote(attrs[i].value) + '"';
+            s += ' ' + attrs[i].name + '=' + wrapQuotes(quote(attrs[i].value), 'double', opts);
         }
         s += '>';
         if (obj.childNodes && obj.childNodes.length) s += '...';
@@ -78,8 +86,12 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
         if (parts.length === 0) return '[' + String(obj) + ']';
         return '{ [' + String(obj) + '] ' + parts.join(', ') + ' }';
     }
-    if (typeof obj === 'object' && typeof obj.inspect === 'function') {
-        return obj.inspect();
+    if (typeof obj === 'object') {
+        if (inspectSymbol && typeof obj[inspectSymbol] === 'function') {
+            return obj[inspectSymbol]();
+        } else if (typeof obj.inspect === 'function') {
+            return obj.inspect();
+        }
     }
     if (isMap(obj)) {
         var parts = [];
@@ -96,7 +108,7 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
         return collectionOf('Set', setSize.call(obj), parts);
     }
     if (isNumber(obj)) {
-        return markBoxed(Number(obj));
+        return markBoxed(inspect(Number(obj)));
     }
     if (isBoolean(obj)) {
         return markBoxed(booleanValueOf.call(obj));
@@ -112,6 +124,11 @@ module.exports = function inspect_ (obj, opts, depth, seen) {
     return String(obj);
 };
 
+function wrapQuotes (s, defaultStyle, opts) {
+    var quoteChar = (opts.quoteStyle || defaultStyle) === 'double' ? '"' : "'";
+    return quoteChar + s + quoteChar;
+}
+
 function quote (s) {
     return String(s).replace(/"/g, '&quot;');
 }
@@ -190,9 +207,9 @@ function isElement (x) {
     ;
 }
 
-function inspectString (str) {
+function inspectString (str, opts) {
     var s = str.replace(/(['\\])/g, '\\$1').replace(/[\x00-\x1f]/g, lowbyte);
-    return "'" + s + "'";
+    return wrapQuotes(s, 'single', opts);
 }
 
 function lowbyte (c) {
