@@ -2,7 +2,7 @@ var inspect = require('../');
 var test = require('tape');
 
 test('element', function (t) {
-    t.plan(1);
+    t.plan(3);
     var elem = {
         nodeName: 'div',
         attributes: [ { name: 'class', value: 'row' } ],
@@ -11,6 +11,8 @@ test('element', function (t) {
     };
     var obj = [ 1, elem, 3 ];
     t.deepEqual(inspect(obj), '[ 1, <div class="row"></div>, 3 ]');
+    t.deepEqual(inspect(obj, { quoteStyle: 'single' }), "[ 1, <div class='row'></div>, 3 ]");
+    t.deepEqual(inspect(obj, { quoteStyle: 'double' }), '[ 1, <div class="row"></div>, 3 ]');
 });
     
 test('element no attr', function (t) {
